import { system, world } from '@minecraft/server';
import { ModalFormData, MessageFormData, ActionFormData} from '@minecraft/server-ui';
import { gunLoop } from './guns/main';
import { bulletEntityImpact } from './guns/bullet';
import 'components/lights';
import 'components/props';

const init = () => {
  autoRunTick();
  events();
};

const tick = () => {
  gunLoop();
};

const autoRunTick = () => {
  tick();
  const timeoutId = system.runTimeout(() => {
    try {
      system.clearRun(timeoutId);
      autoRunTick();
    } catch (error) {
      console.warn(error);
    }
  }, 2);
};

const events = () => {
  world.afterEvents.projectileHitEntity.subscribe(bulletEntityImpact);
  world.afterEvents.entityDie.subscribe((data) => {
    const entitya = data.deadEntity;
    const playera = data.damageSource;
    if (entitya.typeId == "minecraft:player") {
      entitya.addTag("dead")
    }
    if (entitya.typeId == "minecraft:zombie") {
        playera.damagingEntity.runCommandAsync(`scoreboard players add @s points 1`)
        playera.damagingEntity.runCommandAsync(`playsound gun.gun @s`)
        playera.damagingEntity.runCommandAsync(`tellraw @s {"rawtext":[{"text":"§l§e1 Point"}]}`)
    };
    if (entitya.typeId == "minecraft:iron_golem") {
        playera.damagingEntity.runCommandAsync(`scoreboard players add @s points 4`)
        playera.damagingEntity.runCommandAsync(`playsound gun.gun @s`)
        playera.damagingEntity.runCommandAsync(`tellraw @s {"rawtext":[{"text":"§l§e4 Points"}]}`)
    };
  });
  world.afterEvents.itemUse.subscribe((ev)=>{
    if (ev.itemStack.typeId != "converse:menu") return;
    let player = ev.source;
    Menu(player)
  });
};

export function Menu(player) {
  let a = new ActionFormData()
  a.title("game.title.support_menu")
  a.body("§l§eTheEpicFighters v1.7 §k§ai§ci§bi§r")
  a.button("game.button.solve_problems")
  a.button("game.button.back_lobby")
  a.show(player).then(result => {
    if (result.selection == 0){
      SolveProblem(player);
    }
    if (result.selection == 1){
      ConfirmExit(player)
    }
  });
}
export function ConfirmExit(player){
  let d = new MessageFormData()
  d.title("game.title.exit")
  d.body("game.message.exit_confirmation")
  d.button2("game.button.yes")
  d.button1("game.button.no")
  d.show(player).then(result => {
    if (result.selection == 1){
      player.runCommandAsync("function resetallgames");
    }
  });
}
export function SolveProblem(player){
  let b = new ActionFormData()
  b.title("game.title.solve_problems")
  b.body("game.message.what_problem")
  b.button("game.button.player_nodeath")
  b.button("game.button.mode_nowork")
  b.button("game.button.back_menu")
  b.show(player).then(result => {
    if (result.selection == 0){
      player.runCommandAsync("function deathproblem");
    }
    if (result.selection == 1){
      ModeProblem(player);
    }
    if (result.selection == 2){
      Menu(player);
    }
  });
}
export function ModeProblem(player){
  let c = new ActionFormData()
  c.title("game.title.solve_problems")
  c.body("game.button.select_mode")
  c.button("§l§4Battle Royale")
  c.button("§l§eTeam Duel Nuketown")
  c.button("§l§3Team Duel Shipment")
  c.button("§l§5Zombie Invasion")
  c.button("§l§dLevel Guns")
  c.button("§l§nSelect Guns")
  c.button("§l§6More Kills")
  c.button("§l§iHunter")
  c.button("§l§2Base Defender")
  c.button("game.button.back_menu")
  c.show(player).then(result => {
    if (result.selection == 0){
      player.runCommandAsync("execute as @e[type=armor_stand,name=start,scores={games=1}] run function problem1")
      player.runCommandAsync("execute at @e[type=armor_stand,name=start,scores={games=!1}] run execute as @s run function notinmode")
    }
    if (result.selection == 1){
      player.runCommandAsync("execute as @e[type=armor_stand,name=start,scores={games=2}] run function problem2")
      player.runCommandAsync("execute at @e[type=armor_stand,name=start,scores={games=!2}] run execute as @s run function notinmode")
    }
    if (result.selection == 2){
      player.runCommandAsync("execute as @e[type=armor_stand,name=start,scores={games=3}] run function problem3")
      player.runCommandAsync("execute at @e[type=armor_stand,name=start,scores={games=!3}] run execute as @s run function notinmode")
    }
    if (result.selection == 3){
      player.runCommandAsync("execute as @e[type=armor_stand,name=start,scores={games=4}] run function problem4")
      player.runCommandAsync("execute at @e[type=armor_stand,name=start,scores={games=!4}] run execute as @s run function notinmode")
    }
    if (result.selection == 4){
      player.runCommandAsync("execute as @e[type=armor_stand,name=start,scores={games=5}] run function problem5")
      player.runCommandAsync("execute at @e[type=armor_stand,name=start,scores={games=!5}] run execute as @s run function notinmode")
    }
    if (result.selection == 5){
      player.runCommandAsync("execute as @e[type=armor_stand,name=start,scores={games=6}] run function problem6")
      player.runCommandAsync("execute at @e[type=armor_stand,name=start,scores={games=!6}] run execute as @s run function notinmode")
    }
    if (result.selection == 6){
      player.runCommandAsync("execute as @e[type=armor_stand,name=start,scores={games=7}] run function problem7")
      player.runCommandAsync("execute at @e[type=armor_stand,name=start,scores={games=!7}] run execute as @s run function notinmode")
    }
    if (result.selection == 7){
      player.runCommandAsync("execute as @e[type=armor_stand,name=start,scores={games=8}] run function problem8")
      player.runCommandAsync("execute at @e[type=armor_stand,name=start,scores={games=!8}] run execute as @s run function notinmode")
    }
    if (result.selection == 8){
      player.runCommandAsync("execute as @e[type=armor_stand,name=start,scores={games=9}] run function problem9")
      player.runCommandAsync("execute at @e[type=armor_stand,name=start,scores={games=!9}] run execute as @s run function notinmode")
    }
    if (result.selection == 9){
      Menu(player);
    }
  });
}

init();
